import unittest
from os.path import abspath
from subprocess import check_output, CalledProcessError
from docopt import DocoptExit

import sys

sys.path.append("..")
from docker_droplet.exceptions import MissingVariable, PathNotResolvable


class TestInterface(unittest.TestCase):
    fixture_key = abspath("./docker_droplet/tests/fixtures/steve.pub")

    def test_bounce_empty(self) -> None:
        with self.assertRaises(CalledProcessError):
            call_interface()

    def test_path_validation(self) -> None:
        with self.assertRaises(CalledProcessError):
            call_interface(name="steve", ssh_key="99", token="12345")


def call_interface(name=None, ssh_key=None, token=None, config_path=None) -> None:
    call = ["python", "main.py", "up"]
    if name:
        call.append(f"--droplet-name={name}")
    if ssh_key:
        call.append(f"--ssh-key={ssh_key}")
    if token:
        call.append(f"--token={token}")
    if config_path:
        call.append(f"--config-path={config_path}")
    check_output(call, cwd="docker_droplet")


if __name__ == "__main__":
    unittest.main()



import pathlib
from os import chmod, stat
from os.path import dirname, join
from stat import S_IEXEC
from subprocess import run


import sys

sys.path.append("..")
from docker_droplet.terraform.template import create_config


def set_up(droplet_name, ssh_key, token, project, domain, config_path) -> None:
    """ 
    Call functions to create a terraform configuration and then provision the infrastructure with an ansible playbook.
    
    Args:
        droplet_name ([type]):
        ssh_key ([type]):
        token ([type]):
        project ([type]):
        domain ([type]):
        config_path ([type]):
    """

    # Create config from template
    with open(config_path, "w") as config_file:
        config_text = create_config(droplet_name, ssh_key, project, domain)
        config_file.write(config_text)

    # Run terraform from config directory
    run(["terraform", "init"], cwd=dirname(config_path))
    run(["terraform", "apply"], cwd=dirname(config_path))

    # Define ansible paths
    directory = pathlib.Path(__file__).parent.absolute()
    INVENTORY = join(directory, "ansible/inventory")
    INVENTORY_SCRIPT = join(INVENTORY, "digitalocean.py")
    PLAYBOOK = join(directory, "ansible/playbook.yml")

    # Make sure dynamic inventory script is executable
    chmod(INVENTORY_SCRIPT, stat(INVENTORY_SCRIPT).st_mode | S_IEXEC)

    # Provision the droplet
    run(["ansible-playbook", "-i", INVENTORY, PLAYBOOK, "-u", "root"])



#!/usr/bin/env python
import json
from os import environ

from doboto.DO import DO


def main() -> None:
    """
    Dynamic inventory script for Digitalocean. Targets a single specified droplet. Gets access token and droplet name from environment variables. 
    """

    token = environ.get("TF_VAR_DOCKER_DROPLET_TOKEN")
    name = environ.get("TF_VAR_DOCKER_DROPLET_DROPLET_NAME")

    client = DO(token=token)
    hosts = [
        d["networks"]["v4"][0]["ip_address"]
        for d in client.droplet.list()
        if d["name"] == name
    ]

    # Terraform creates them in this order
    hosts.reverse()

    print(
        json.dumps(
            {"_meta": {"hostvars": {}}, "instances": {"hosts": hosts, "vars": {},},}
        )
    )


if __name__ == "__main__":
    main()



import unittest
import pathlib
from jinja2 import Environment, FileSystemLoader
from jinja2.exceptions import TemplateNotFound


class TestTemplate(unittest.TestCase):
    def test_loader(self) -> None:
        directory = pathlib.Path("docker_droplet/terraform/").absolute()
        templateLoader = FileSystemLoader(searchpath=directory)
        templateEnv = Environment(loader=templateLoader)

        try:
            templateEnv.get_template("providers.jinja2")
            templateEnv.get_template("digitalocean.jinja2")
        except TemplateNotFound:
            self.fail("Jinja templates not found")


if __name__ == "__main__":
    unittest.main()



import subprocess
from setuptools import find_packages, setup
from distutils.core import Command

__version__ = "1.0.8"

with open("README.md", "r") as f:
    long_description = f.read()


class UpdateDocs(Command):
    description = "Update build configuration using sphinx-apidoc"
    user_options = []

    def initialize_options(self) -> None:
        self.version = __version__

    def finalize_options(self) -> None:
        pass

    def run(self) -> None:
        subprocess.run(["sphinx-apidoc", "-o", "docs/", "src/", "tests/"])


class GenerateDocs(Command):
    description = "Generate docs using sphinx-autodoc"
    user_options = []

    def initialize_options(self) -> None:
        self.version = __version__

    def finalize_options(self) -> None:
        pass

    def run(self) -> None:
        subprocess.run(["sphinx-build", "docs/", "build/"])


s = setup(
    name="docker-droplet",
    version=__version__,
    license="MIT",
    description="Create a single digital ocean droplet and provision it to run the docker engine over a simple cli",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/JoelLefkowitz/docker-droplet",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "docopts>=0.6.1",
        "ansible>=2.8.0",
        "jinja2>=2.11.1",
        "doboto>=0.6.1",
    ],
    entry_points={"console_scripts": ["docker-droplet=docker_droplet.main:main"]},
    cmdclass={"updateDocs": UpdateDocs, "generateDocs": GenerateDocs},
    python_requires=">= 3.6",
    author="Joel Lefkowitz",
    author_email="joellefkowitz@hotmail.com",
)



from os.path import dirname, abspath, join

project = "docker-droplet"
copyright = "2020, Joel Lefkowitz"
author = "Joel Lefkowitz"

master_doc = "docker_droplet/docs/modules"
output_dir = dirname(abspath(__file__))
source_dir = dirname(abspath(join(__file__, "..")))

extensions = ["sphinx.ext.napoleon", "sphinx.ext.autodoc", "sphinxcontrib.apidoc"]

apidoc_module_dir = source_dir
apidoc_output_dir = output_dir
apidoc_extra_args = ["-d=1"]

napoleon_google_docstring = True
napoleon_numpy_docstring = True
napoleon_include_init_with_doc = False
napoleon_include_private_with_doc = False
napoleon_include_special_with_doc = True
napoleon_use_admonition_for_examples = False
napoleon_use_admonition_for_notes = False
napoleon_use_admonition_for_references = False
napoleon_use_ivar = False
napoleon_use_param = True
napoleon_use_rtype = True

# Must exclude venv rst files
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store", "venv"]
html_theme = "yummy_sphinx_theme"
